package com.orhanobut.dialogplus;

import android.app.Activity;
import android.content.Context;
import android.view.KeyEvent;
import android.view.LayoutInflater;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.view.animation.Animation;
import android.widget.AbsListView;
import android.widget.AdapterView;
import android.widget.BaseAdapter;
import android.widget.FrameLayout;

public class DialogPlus {
    private static final int INVALID = -1;
    private final ViewGroup contentContainer;
    private final ViewGroup decorView;
    private final Holder holder;
    private final Animation inAnim;
    private final boolean isCancelable;
    private boolean isDismissing;
    private final OnBackPressListener onBackPressListener;
    private final OnCancelListener onCancelListener;
    private final View.OnTouchListener onCancelableTouchListener = new View.OnTouchListener() {
        /* class com.orhanobut.dialogplus.DialogPlus.AnonymousClass5 */

        public boolean onTouch(View v, MotionEvent event) {
            if (event.getAction() != 0) {
                return false;
            }
            if (DialogPlus.this.onCancelListener != null) {
                DialogPlus.this.onCancelListener.onCancel(DialogPlus.this);
            }
            DialogPlus.this.dismiss();
            return false;
        }
    };
    private final OnClickListener onClickListener;
    private final OnDismissListener onDismissListener;
    private final OnItemClickListener onItemClickListener;
    private final Animation outAnim;
    private final ViewGroup rootView;

    DialogPlus(DialogPlusBuilder builder) {
        LayoutInflater layoutInflater = LayoutInflater.from(builder.getContext());
        Activity activity = (Activity) builder.getContext();
        this.holder = builder.getHolder();
        this.onItemClickListener = builder.getOnItemClickListener();
        this.onClickListener = builder.getOnClickListener();
        this.onDismissListener = builder.getOnDismissListener();
        this.onCancelListener = builder.getOnCancelListener();
        this.onBackPressListener = builder.getOnBackPressListener();
        this.isCancelable = builder.isCancelable();
        this.decorView = (ViewGroup) activity.getWindow().getDecorView().findViewById(16908290);
        this.rootView = (ViewGroup) layoutInflater.inflate(R.layout.base_container, this.decorView, false);
        this.rootView.setLayoutParams(builder.getOutmostLayoutParams());
        this.contentContainer = (ViewGroup) this.rootView.findViewById(R.id.content_container);
        this.contentContainer.setLayoutParams(builder.getContentParams());
        this.outAnim = builder.getOutAnimation();
        this.inAnim = builder.getInAnimation();
        initContentView(layoutInflater, builder.getHeaderView(), builder.getFooterView(), builder.getAdapter(), builder.getContentPadding(), builder.getContentMargin());
        initCancelable();
        if (builder.isExpanded()) {
            initExpandAnimator(activity, builder.getDefaultContentHeight(), builder.getContentParams().gravity);
        }
    }

    public static DialogPlusBuilder newDialog(Context context) {
        return new DialogPlusBuilder(context);
    }

    public void show() {
        if (!isShowing()) {
            onAttached(this.rootView);
        }
    }

    public boolean isShowing() {
        return this.decorView.findViewById(R.id.outmost_container) != null;
    }

    public void dismiss() {
        if (!this.isDismissing) {
            this.outAnim.setAnimationListener(new Animation.AnimationListener() {
                /* class com.orhanobut.dialogplus.DialogPlus.AnonymousClass1 */

                public void onAnimationStart(Animation animation) {
                }

                public void onAnimationEnd(Animation animation) {
                    DialogPlus.this.decorView.post(new Runnable() {
                        /* class com.orhanobut.dialogplus.DialogPlus.AnonymousClass1.AnonymousClass1 */

                        public void run() {
                            DialogPlus.this.decorView.removeView(DialogPlus.this.rootView);
                            DialogPlus.this.isDismissing = false;
                            if (DialogPlus.this.onDismissListener != null) {
                                DialogPlus.this.onDismissListener.onDismiss(DialogPlus.this);
                            }
                        }
                    });
                }

                public void onAnimationRepeat(Animation animation) {
                }
            });
            this.contentContainer.startAnimation(this.outAnim);
            this.isDismissing = true;
        }
    }

    public View findViewById(int resourceId) {
        return this.contentContainer.findViewById(resourceId);
    }

    public View getHeaderView() {
        return this.holder.getHeader();
    }

    public View getFooterView() {
        return this.holder.getFooter();
    }

    public View getHolderView() {
        return this.holder.getInflatedView();
    }

    private void initExpandAnimator(Activity activity, int defaultHeight, int gravity) {
        int displayHeight = activity.getWindowManager().getDefaultDisplay().getHeight() - Utils.getStatusBarHeight(activity);
        if (defaultHeight == 0) {
            defaultHeight = (displayHeight * 2) / 5;
        }
        View view = this.holder.getInflatedView();
        if (view instanceof AbsListView) {
            view.setOnTouchListener(ExpandTouchListener.newListener(activity, (AbsListView) view, this.contentContainer, gravity, displayHeight, defaultHeight));
        }
    }

    private void initContentView(LayoutInflater inflater, View header, View footer, BaseAdapter adapter, int[] padding, int[] margin) {
        View contentView = createView(inflater, header, footer, adapter);
        FrameLayout.LayoutParams params = new FrameLayout.LayoutParams(-1, -1);
        params.setMargins(margin[0], margin[1], margin[2], margin[3]);
        contentView.setLayoutParams(params);
        getHolderView().setPadding(padding[0], padding[1], padding[2], padding[3]);
        this.contentContainer.addView(contentView);
    }

    private void initCancelable() {
        if (this.isCancelable) {
            this.rootView.findViewById(R.id.outmost_container).setOnTouchListener(this.onCancelableTouchListener);
        }
    }

    private View createView(LayoutInflater inflater, View headerView, View footerView, BaseAdapter adapter) {
        View view = this.holder.getView(inflater, this.rootView);
        if (this.holder instanceof ViewHolder) {
            assignClickListenerRecursively(view);
        }
        assignClickListenerRecursively(headerView);
        this.holder.addHeader(headerView);
        assignClickListenerRecursively(footerView);
        this.holder.addFooter(footerView);
        if (adapter != null && (this.holder instanceof HolderAdapter)) {
            HolderAdapter holderAdapter = (HolderAdapter) this.holder;
            holderAdapter.setAdapter(adapter);
            holderAdapter.setOnItemClickListener(new OnHolderListener() {
                /* class com.orhanobut.dialogplus.DialogPlus.AnonymousClass2 */

                @Override // com.orhanobut.dialogplus.OnHolderListener
                public void onItemClick(Object item, View view, int position) {
                    if (DialogPlus.this.onItemClickListener != null) {
                        DialogPlus.this.onItemClickListener.onItemClick(DialogPlus.this, item, view, position);
                    }
                }
            });
        }
        return view;
    }

    private void assignClickListenerRecursively(View parent) {
        if (parent != null) {
            if (parent instanceof ViewGroup) {
                ViewGroup viewGroup = (ViewGroup) parent;
                for (int i = viewGroup.getChildCount() - 1; i >= 0; i--) {
                    assignClickListenerRecursively(viewGroup.getChildAt(i));
                }
            }
            setClickListener(parent);
        }
    }

    private void setClickListener(View view) {
        if (view.getId() != -1 && !(view instanceof AdapterView)) {
            view.setOnClickListener(new View.OnClickListener() {
                /* class com.orhanobut.dialogplus.DialogPlus.AnonymousClass3 */

                public void onClick(View v) {
                    if (DialogPlus.this.onClickListener != null) {
                        DialogPlus.this.onClickListener.onClick(DialogPlus.this, v);
                    }
                }
            });
        }
    }

    private void onAttached(View view) {
        this.decorView.addView(view);
        this.contentContainer.startAnimation(this.inAnim);
        this.contentContainer.requestFocus();
        this.holder.setOnKeyListener(new View.OnKeyListener() {
            /* class com.orhanobut.dialogplus.DialogPlus.AnonymousClass4 */

            public boolean onKey(View v, int keyCode, KeyEvent event) {
                switch (event.getAction()) {
                    case 1:
                        if (keyCode == 4) {
                            if (DialogPlus.this.onBackPressListener != null) {
                                DialogPlus.this.onBackPressListener.onBackPressed(DialogPlus.this);
                            }
                            if (DialogPlus.this.isCancelable) {
                                DialogPlus.this.onBackPressed(DialogPlus.this);
                            }
                            return true;
                        }
                        break;
                }
                return false;
            }
        });
    }

    public void onBackPressed(DialogPlus dialogPlus) {
        if (this.onCancelListener != null) {
            this.onCancelListener.onCancel(this);
        }
        dismiss();
    }
}
